spacepy.pycdf.zAttr — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »

# spacepy.pycdf.zAttr

class `spacepy.pycdf.` `zAttr`(*args, **kwargs)

  zAttribute for zVariables within a CDF.

  Warning

  Because zAttributes are shared across all variables in a CDF, directly manipulating them may have unexpected consequences. It is safest to operate on zEntries via `zAttrList`.

  Note

  When accessing a zAttr, pyCDF exposes only the zEntry corresponding to the associated zVariable.

  See also

  `Attr`

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »